Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(917)

Unified Diff: remoting/signaling/server_log_entry_unittest.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/signaling/server_log_entry_unittest.h ('k') | remoting/signaling/xmpp_signal_strategy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/signaling/server_log_entry_unittest.cc
diff --git a/remoting/signaling/server_log_entry_unittest.cc b/remoting/signaling/server_log_entry_unittest.cc
index 4f9b0aabc30e526047004a721905e1f8276a53bd..ac3506d3746f557e110df58019266d231603f31c 100644
--- a/remoting/signaling/server_log_entry_unittest.cc
+++ b/remoting/signaling/server_log_entry_unittest.cc
@@ -21,16 +21,16 @@ const char kChromotingNamespace[] = "google:remoting";
XmlElement* GetLogElementFromStanza(XmlElement* stanza) {
if (stanza->Name() != QName(kJabberClientNamespace, "iq")) {
ADD_FAILURE() << "Expected element 'iq'";
- return NULL;
+ return nullptr;
}
XmlElement* log_element = stanza->FirstChild()->AsElement();
if (log_element->Name() != QName(kChromotingNamespace, "log")) {
ADD_FAILURE() << "Expected element 'log'";
- return NULL;
+ return nullptr;
}
if (log_element->NextChild()) {
ADD_FAILURE() << "Expected only 1 child of 'iq'";
- return NULL;
+ return nullptr;
}
return log_element;
}
@@ -38,17 +38,17 @@ XmlElement* GetLogElementFromStanza(XmlElement* stanza) {
XmlElement* GetSingleLogEntryFromStanza(XmlElement* stanza) {
XmlElement* log_element = GetLogElementFromStanza(stanza);
if (!log_element) {
- // Test failure already recorded, so just return NULL here.
- return NULL;
+ // Test failure already recorded, so just return nullptr here.
+ return nullptr;
}
XmlElement* entry = log_element->FirstChild()->AsElement();
if (entry->Name() != QName(kChromotingNamespace, "entry")) {
ADD_FAILURE() << "Expected element 'entry'";
- return NULL;
+ return nullptr;
}
if (entry->NextChild()) {
ADD_FAILURE() << "Expected only 1 child of 'log'";
- return NULL;
+ return nullptr;
}
return entry;
}
@@ -59,7 +59,7 @@ bool VerifyStanza(
const XmlElement* elem,
std::string* error) {
int attrCount = 0;
- for (const XmlAttr* attr = elem->FirstAttr(); attr != NULL;
+ for (const XmlAttr* attr = elem->FirstAttr(); attr != nullptr;
attr = attr->NextAttr(), attrCount++) {
if (attr->Name().Namespace().length() != 0) {
*error = "attribute has non-empty namespace " +
« no previous file with comments | « remoting/signaling/server_log_entry_unittest.h ('k') | remoting/signaling/xmpp_signal_strategy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698